@@ -392,13 +392,21 @@
  *
  * Possible values:
  *
- *  1 - perform PCI configuration space checks (default)
- *  0 - do not perform PCI configuration space checks
+ *  1 - perform PCI configuration space checks (default on non-virtualized system)
+ *  0 - do not perform PCI configuration space checks (default on virtual machine)
+ *
+ *  Dummy value:
+ *  0xFFFFFFFF: It is only used to detect if user has over-ridden the value.
+ *              We should never see this value after registry init.
  */
 
 #define __NV_CHECK_PCI_CONFIG_SPACE  CheckPCIConfigSpace
 #define NV_REG_CHECK_PCI_CONFIG_SPACE NV_REG_STRING(__NV_CHECK_PCI_CONFIG_SPACE)
 
+#define NV_CHECK_PCI_CONFIG_SPACE_DISABLED          0
+#define NV_CHECK_PCI_CONFIG_SPACE_ENABLED           1
+#define NV_CHECK_PCI_CONFIG_SPACE_INIT     0xFFFFFFFF
+
 /*
  * Option: AssignGpus
  *
@@ -474,7 +482,7 @@ NV_DEFINE_REG_ENTRY(__NV_RM_EDGE_INTR_CHECK, 1);
 NV_DEFINE_REG_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE, ~0);
 NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
 NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
-NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, 1);
+NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, NV_CHECK_PCI_CONFIG_SPACE_INIT);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 1);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_MEMORY_POOL_SIZE, 0);
