@@ -319,6 +319,7 @@ typedef struct
     /* PCI config info */
     nv_pci_info_t pci_info;
     NvU16 subsystem_id;
+    NvU16 subsystem_vendor;
     NvU32 gpu_id;
     void *handle;
 
@@ -343,7 +344,10 @@ typedef struct
     nv_kern_mapping_t *kern_mappings;
 
     nv_mmap_context_t *mmap_contexts;
-
+ 
+    /* DMA addressable range of the device */
+    NvU64 dma_addressable_start;
+    NvU64 dma_addressable_limit;
 } nv_state_t;
 
 // Forward define the gpu ops structures
@@ -456,6 +460,10 @@ typedef struct
 #define NV_GET_NV_STATE(pGpu) \
     (nv_state_t *)((pGpu) ? (pGpu)->pOsHwInfo : NULL)
 
+#define IS_DMA_ADDRESSABLE(nv, offset)                                          \
+    (((offset) >= (nv)->dma_addressable_start) &&                               \
+     ((offset) <= (nv)->dma_addressable_limit))
+
 #define IS_REG_OFFSET(nv, offset, length)                                       \
     (((offset) >= (nv)->regs->cpu_address) &&                                   \
     (((offset) + ((length)-1)) <=                                               \
@@ -656,7 +664,7 @@ NvU64      NV_API_CALL  nv_rdtsc                 (void);
 void       NV_API_CALL  rm_register_compatible_ioctls   (nv_stack_t *);
 void       NV_API_CALL  rm_unregister_compatible_ioctls (nv_stack_t *);
 
-BOOL       NV_API_CALL  rm_is_legacy_device      (nv_stack_t *, NvU16, BOOL);
+BOOL       NV_API_CALL  rm_is_legacy_device      (nv_stack_t *, NvU16, NvU16, NvU16, BOOL);
 BOOL       NV_API_CALL  rm_is_legacy_arch        (NvU32, NvU32);
 RM_STATUS  NV_API_CALL  rm_is_supported_device   (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *);
 
